@@ -543,20 +543,18 @@ Read Info node `(elisp) Desktop Notifications' for details."
          :app-icon 'emacs
          :urgency tmr-notification-urgency
          :sound-file tmr-sound-file))
-    (warn "Emacs has no DBUS support, TMR notifications unavailable")))
+    (display-warning 'tmr "Emacs has no DBUS support, TMR notifications unavailable")))
 
 ;; NOTE 2022-04-21: Emacs has a `play-sound' function but it only
 ;; supports .wav and .au formats.  Also, it does not work on all
 ;; platforms and Emacs needs to be compiled --with-sound capabilities.
-(defun tmr-sound-play (&optional _timer)
-  "Play `tmr-sound-file' using the ffplay executable (ffmpeg).
-TIMER is unused."
-  (when-let* ((sound tmr-sound-file)
-              ((file-exists-p sound)))
-    (unless (executable-find "ffplay")
-      (user-error "Cannot play %s without `ffplay'" sound))
-    (call-process-shell-command
-     (format "ffplay -nodisp -autoexit %s >/dev/null 2>&1" sound) nil 0)))
+(defun tmr-sound-play (&rest _)
+  "Play `tmr-sound-file' using the ffplay executable (ffmpeg)."
+  (if (executable-find "ffplay")
+      (when-let* ((sound (expand-file-name tmr-sound-file))
+                  (_ (file-exists-p sound)))
+        (call-process "ffplay" nil 0 nil "-nodisp" "-autoexit" sound))
+    (display-warning 'tmr "`ffplay' is not available to play back `tmr-sound-file'")))
 
 (defun tmr-print-message-for-created-timer (timer)
   "Show a `message' informing the user that TIMER was created."
@@ -1010,9 +1008,13 @@ they are set to reasonable default values."
 
 ;;;; Ask if there are timers before exiting Emacs
 
+(defun tmr-running-timers-p ()
+  "Return non-nil if there are running timers."
+  (and tmr--timers (seq-remove #'tmr--timer-finishedp tmr--timers)))
+
 (defun tmr-kill-emacs-query-function ()
   "Ask before exiting Emacs if there are any active TMR timers."
-  (if (not (and tmr--timers (seq-remove #'tmr--timer-finishedp tmr--timers)))
+  (if (not (tmr-running-timers-p))
       t
     (tmr-tabulated-view
      (get-buffer-create "*tmr-tabulated-view*")
